TestEnv

Struct TestEnv 

pub struct TestEnv { /* private fields */ }
Test environment with regtest Liquid node and servers

Use TestEnvBuilder to configure and build

Implementations

Source

impl TestEnv

pub fn zmq_endpoint(&self) -> String

pub fn electrum_url(&self) -> String

pub fn esplora_url(&self) -> String

pub fn waterfalls_url(&self) -> String

pub fn registry_url(&self) -> String

pub fn elements_rpc_url(&self) -> String

pub fn elements_rpc_credentials(&self) -> (String, String)

pub fn elementsd_call(&self, cmd: &str, args: &[Value]) -> Value

pub fn elementsd_getnewaddress(&self) -> Address

pub fn elementsd_generate(&self, blocks: u32)

pub fn elementsd_sendtoaddress( &self, address: &Address, satoshi: u64, asset: Option<AssetId>, ) -> Txid

pub fn elementsd_issueasset(&self, satoshi: u64) -> AssetId

pub fn elementsd_height(&self) -> u64

pub fn elementsd_genesis_block_hash(&self) -> BlockHash

Get the genesis block hash from the running elementsd node.

Could differ from the hardcoded one because parameters like -initialfreecoins change the genesis hash.

pub fn elementsd_getpeginaddress(&self) -> (Address, String)

pub fn elementsd_raw_createpsbt(&self, inputs: Value, outputs: Value) -> String

pub fn elementsd_expected_next(&self, base64: &str) -> String

pub fn elementsd_walletprocesspsbt(&self, psbt: &str) -> String

pub fn elementsd_finalizepsbt(&self, psbt: &str) -> String

pub fn elementsd_sendrawtransaction(&self, tx: &str) -> String

pub fn elementsd_testmempoolaccept(&self, tx: &str) -> bool

pub fn bitcoind(&self) -> &BitcoinD

pub fn bitcoind_generate(&self, blocks: u32)

pub fn bitcoind_sendtoaddress(&self, address: &Address, satoshi: u64) -> Txid

pub fn bitcoind_getrawtransaction(&self, txid: Txid) -> Transaction

pub fn bitcoind_gettxoutproof(&self, txid: Txid) -> String